Date: 2017-11-20

# Serialized Form

- ## Package jep

  - ### Class jep.JepException extends java.lang.Exception implements Serializable

    serialVersionUID:
      1L

    - ### Serialized Fields

      - #### pythonType

            long pythonType

        The address of the Python type which caused this exception. This is used if the JepException is thrown back into Python so that a new Python exception can be thrown with the same type as the original exception.
        Since:
          3.7

  - ### Class jep.Proxy extends java.lang.reflect.Proxy implements Serializable

    serialVersionUID:
      1L